@@ -5,7 +5,6 @@
 #' @param y a numeric vector.
 #' @param type options: ("discrete", "continuous"); \code{"discrete"} (default) selects the type of CDF.
 #' @return Returns (1) if \code{"X FSD Y"}, else (0).
-#' @keywords stochastic dominance
 #' @author Fred Viole, OVVO Financial Systems
 #' @references Viole, F. and Nawrocki, D. (2016) "LPM Density Functions for the Computation of the SD Efficient Set." Journal of Mathematical Finance, 6, 105-126. \url{http://www.scirp.org/Journal/PaperInformation.aspx?PaperID=63817}.
 #'
@@ -18,26 +17,26 @@
 
 NNS.FSD.uni <- function(x, y, type = "discrete"){
   if(min(y) > min(x)){
-    return(0)
-    } else {
+      return(0)
+  } else {
       x_sort <- sort(x, decreasing = FALSE)
       y_sort <- sort(y, decreasing = FALSE)
 
-      Combined = c(x_sort, y_sort)
-      Combined_sort = sort(Combined, decreasing = FALSE)
+      Combined <- c(x_sort, y_sort)
+      Combined_sort <- sort(Combined, decreasing = FALSE)
 
       if(type == "discrete"){
-        degree = 0
+          degree <- 0
       } else {
-          degree = 1
+          degree <- 1
       }
 
-      L.x = LPM(degree, Combined_sort, x)
-      LPM_x_sort = L.x / (UPM(degree, Combined_sort, x) + L.x)
-      L.y = LPM(degree, Combined_sort, y)
-      LPM_y_sort = L.y / (UPM(degree, Combined_sort, y) + L.y)
+      L.x <- LPM(degree, Combined_sort, x)
+      LPM_x_sort <- L.x / (UPM(degree, Combined_sort, x) + L.x)
+      L.y <- LPM(degree, Combined_sort, y)
+      LPM_y_sort <- L.y / (UPM(degree, Combined_sort, y) + L.y)
 
-      x.fsd.y = any(LPM_x_sort > LPM_y_sort)
+      x.fsd.y <- any(LPM_x_sort > LPM_y_sort)
 
       ifelse(!x.fsd.y & min(x) >= min(y) & !identical(LPM_x_sort, LPM_y_sort), return(1), return(0))
 
@@ -61,18 +60,18 @@ NNS.FSD.uni <- function(x, y, type = "discrete"){
 
 NNS.SSD.uni <- function(x, y){
   if(min(y) > min(x) | mean(y) > mean(x)) {
-    return(0)
-    } else {
+      return(0)
+  } else {
       x_sort <- sort(x, decreasing = FALSE)
       y_sort <- sort(y, decreasing = FALSE)
 
-      Combined = c(x_sort, y_sort)
-      Combined_sort = sort(Combined, decreasing = FALSE)
+      Combined <- c(x_sort, y_sort)
+      Combined_sort <- sort(Combined, decreasing = FALSE)
 
-      LPM_x_sort = LPM(1, Combined_sort, x)
-      LPM_y_sort = LPM(1, Combined_sort, y)
+      LPM_x_sort <- LPM(1, Combined_sort, x)
+      LPM_y_sort <- LPM(1, Combined_sort, y)
 
-      x.ssd.y=any(LPM_x_sort > LPM_y_sort)
+      x.ssd.y <- any(LPM_x_sort > LPM_y_sort)
 
       ifelse(!x.ssd.y & min(x) >= min(y) & !identical(LPM_x_sort, LPM_y_sort), return(1), return(0))
 
@@ -97,18 +96,18 @@ NNS.SSD.uni <- function(x, y){
 
 NNS.TSD.uni <- function(x, y){
   if(min(y) > min(x) | mean(y) > mean(x)) {
-    return(0)
-    } else {
+      return(0)
+  } else {
       x_sort <- sort(x, decreasing = FALSE)
       y_sort <- sort(y, decreasing = FALSE)
 
-      Combined = c(x_sort, y_sort)
-      Combined_sort = sort(Combined, decreasing = FALSE)
+      Combined <- c(x_sort, y_sort)
+      Combined_sort <- sort(Combined, decreasing = FALSE)
 
-      LPM_x_sort = LPM(2, Combined_sort, x)
-      LPM_y_sort = LPM(2, Combined_sort, y)
+      LPM_x_sort <- LPM(2, Combined_sort, x)
+      LPM_y_sort <- LPM(2, Combined_sort, y)
 
-      x.tsd.y = any(LPM_x_sort > LPM_y_sort)
+      x.tsd.y <- any(LPM_x_sort > LPM_y_sort)
 
       ifelse(!x.tsd.y & min(x) >= min(y) & !identical(LPM_x_sort, LPM_y_sort), return(1), return(0))
 
